@@ -217,9 +217,9 @@ option_app_id_cb (const gchar *option_name,
 {
   OptionData *data = user_data;
 
-  if (!g_dbus_is_name (value)) {
+  if (!g_application_id_is_valid (value)) {
     g_set_error (error, G_OPTION_ERROR, G_OPTION_ERROR_BAD_VALUE,
-                 "%s is not a valid D-Bus name", value);
+                 "\"%s\" is not a valid application ID", value);
     return FALSE;
   }
 
@@ -517,17 +517,8 @@ parse_arguments (int *argcp,
     return NULL;
   }
 
-  if (data->working_directory == NULL) {
-    char *cwd;
-
-    /* We use get_current_dir_name() here instead of getcwd / g_get_current_dir()
-     * because we want to use the value from PWD (if it is correct).
-     * See bug 502146.
-     */
-    cwd = get_current_dir_name ();
-    data->working_directory = g_strdup (cwd);
-    free (cwd);
-  }
+  if (data->working_directory == NULL)
+    data->working_directory = g_get_current_dir ();
 
   /* Do this here so that gdk_display is initialized */
   if (data->startup_id == NULL)
@@ -781,10 +772,6 @@ main (gint argc, gchar *argv[])
 
   terminal_i18n_init (TRUE);
 
-#if !GLIB_CHECK_VERSION (2, 35, 3)
-  g_type_init ();
-#endif
-
   _terminal_debug_init ();
 
   ret = EXIT_FAILURE;
